==> cppad_2014.00.00.3.orig.tar.gz: cppad-20140000.3/doc/_get_colpack.sh_xml.js <==
var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'install.xml',
'cmake.xml',
'adolc_prefix.xml',
'get_adolc.sh.xml',
'get_colpack.sh.xml'
];
var list_down3 = [
'adolc_prefix.xml',
'eigen_prefix.xml',
'fadbad_prefix.xml',
'ipopt_prefix.xml',
'sacado_prefix.xml',
'cppad_testvector.xml'
];
var list_down2 = [
'get_adolc.sh.xml'
];
var list_down1 = [
'get_colpack.sh.xml'
];
var list_current0 = [
'get_colpack.sh.xml#Syntax',
'get_colpack.sh.xml#Purpose',
'get_colpack.sh.xml#Distribution Directory',
'get_colpack.sh.xml#External Directory',
'get_colpack.sh.xml#Prefix Directory',
'get_colpack.sh.xml#Reuse'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down3(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down3[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}

==> cppad_2015.00.00.9.orig.tar.gz: cppad-20150000.9/doc/_get_colpack.sh_xml.js <==
var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'install.xml',
'cmake.xml',
'colpack_prefix.xml',
'get_colpack.sh.xml'
];
var list_down3 = [
'download.xml',
'cmake.xml',
'cmake_check.xml',
'pkgconfig.xml',
'installunix.xml'
];
var list_down2 = [
'adolc_prefix.xml',
'colpack_prefix.xml',
'eigen_prefix.xml',
'fadbad_prefix.xml',
'ipopt_prefix.xml',
'sacado_prefix.xml',
'cppad_testvector.xml'
];
var list_down1 = [
'colpack.cpp.xml',
'get_colpack.sh.xml'
];
var list_current0 = [
'get_colpack.sh.xml#Syntax',
'get_colpack.sh.xml#Purpose',
'get_colpack.sh.xml#Distribution Directory',
'get_colpack.sh.xml#External Directory',
'get_colpack.sh.xml#Prefix Directory',
'get_colpack.sh.xml#Reuse'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down3(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down3[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}
